@@ -39,9 +39,10 @@ def prep_sliiders(
     expand_exposure=True,
     storage_options={},
 ):
-    """Import the SLIIDERS dataset (or a different dataset formatted analogously),
-    format, and calculate derived variables so that it can be used by the functions that
-    implement pyCIAM.
+    """Import the SLIIDERS dataset (or a different dataset formatted analogously).
+
+    Input, format, and calculate derived variables so that it can be used by the
+    functions that implement pyCIAM.
 
     Parameters
     ----------
@@ -140,7 +141,7 @@ def prep_sliiders(
     if "dfact" not in inputs.data_vars and "npv_start" in inputs.data_vars:
         inputs["dfact"] = (1 / (1 + inputs.dr)) ** (inputs.year - inputs.npv_start)
 
-    if "landrent" or "ypc" not in inputs.data_vars:
+    if "landrent" not in inputs.data_vars or "ypc" not in inputs.data_vars:
         area = inputs.landarea
         if calc_popdens_with_wetland_area:
             area = area + inputs.wetland
@@ -161,7 +162,7 @@ def prep_sliiders(
 
         if (
             "ypc" not in inputs.data_vars
-            and "min_pyc_scale" in inputs.data_vars
+            and "min_ypc_scale" in inputs.data_vars
             and "ypc_scale_denom" in inputs.data_vars
             and "ypc_scale_elast" in inputs.data_vars
         ):
@@ -309,14 +310,16 @@ def _load_lslr_for_ciam(
             .set_index(scen_mc=ix_names)
         )
 
-    # interpolate to yearly
+    # add on base year where slr is 0
     slr_out = slr_out.reindex(
         year=np.concatenate(([slr_0_year], slr.year.values)),
         fill_value=0,
     )
 
+    # interpolate to desired years
     if interp_years is not None:
         slr_out = slr_out.interp(year=interp_years)
+
     return slr_out
 
 
